@@ -19,8 +19,9 @@ YahooConnection = JavaScriptViewlet('yui/build/connection/connection.js')
 YahooDom = JavaScriptViewlet('yui/build/dom/dom.js')
 YahooCore = JavaScriptViewlet('yui/build/yahoo-dom-event/yahoo-dom-event.js')
 YahooLogger = JavaScriptViewlet('yui/build/logger/logger-min.js')
-YahooElement = JavaScriptViewlet('yui/build/element/element-beta.js')
-YahooDataSource = JavaScriptViewlet('yui/build/datasource/datasource-beta.js')
-YahooDataTable = JavaScriptViewlet('yui/build/datatable/datatable-beta.js')
+YahooElement = JavaScriptViewlet('yui/build/element/element.js')
+YahooDataSource = JavaScriptViewlet('yui/build/datasource/datasource.js')
+YahooDataTable = JavaScriptViewlet('yui/build/datatable/datatable.js')
 YahooTree = JavaScriptViewlet('yui/build/treeview/treeview.js')
 YahooSelector = JavaScriptViewlet('yui/build/selector/selector.js')
+YahooTabView = JavaScriptViewlet('yui/build/tabview/tabview.js')
